==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
export let GridColumnHideOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnHideOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnHideOptionsDescriptionMetadata.a == null) {
                GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnHideOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridColumnHideOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnHideOptionsDescriptionMetadata.b(a);
            a.ad("GridColumnHideOptions", () => new GridColumnHideOptionsDescription());
            a.ac("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
        }
    }
    GridColumnHideOptionsDescriptionMetadata.$t = markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridColumnHideOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsSimpleSectionBaseDescriptionMetadata } from "./GridColumnOptionsSimpleSectionBaseDescriptionMetadata";
import { GridColumnHideOptionsDescription } from "./GridColumnHideOptionsDescription";
/**
 * @hidden
 */
export let GridColumnHideOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnHideOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnHideOptionsDescriptionMetadata.a == null) {
                GridColumnHideOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnHideOptionsDescriptionMetadata.c(GridColumnHideOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnHideOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridColumnHideOptionsDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsSimpleSectionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnHideOptionsDescriptionMetadata.b(a);
            a.ae("GridColumnHideOptions", () => new GridColumnHideOptionsDescription());
            a.ad("GridColumnHideOptions", GridColumnHideOptionsDescriptionMetadata.a);
        }
    }
    GridColumnHideOptionsDescriptionMetadata.$t = markType(GridColumnHideOptionsDescriptionMetadata, 'GridColumnHideOptionsDescriptionMetadata');
    GridColumnHideOptionsDescriptionMetadata.a = null;
    return GridColumnHideOptionsDescriptionMetadata;
})();
